==> redturtle.filesretriever-1.0.1.tar.gz: redturtle.filesretriever-1.0.1/src/redturtle/filesretriever/restapi/services/files_list.py <==
# -*- coding: utf-8 -*-
from bs4 import BeautifulSoup
from plone.restapi.deserializer import json_body
from plone.restapi.services import Service
from redturtle.filesretriever import _
from requests.exceptions import RequestException
from requests.exceptions import Timeout
from urllib.parse import urlparse
from zope.i18n import translate

import logging
import requests


logger = logging.getLogger(__name__)

HREF_NOT_VALID = ["", None, "#"]


class FilesListService(Service):
    """ """

    def reply(self):
        query = json_body(self.request)
        url = query.get("url", "")

        html = self.fetch_html(url)
        if not html:
            return {}

        css_class = query.get("class", "")
        css_id = query.get("id", "")
        links = self.extract_links(
            html=html, css_class=css_class, css_id=css_id, url=url
        )
        return {"links": links}

    def fetch_html(self, url):
        """ """
        try:
            response = requests.get(url, timeout=10)
        except Timeout as e:
            logger.exception(e)
            return dict(
                error=dict(
                    code="408",
                    type="Timeout",
                    message=translate(
                        _(
                            "request_timeout",
                            default="Unable to fetch data from given url (${url}): timeout. Retry later.",
                            mapping=dict(url=url),
                        ),
                        context=self.request,
                    ),
                )
            )
        except RequestException as e:
            logger.exception(e)
            return dict(
                error=dict(
                    code="500",
                    type="InternalServerError",
                    message=translate(
                        _(
                            "request_error",
                            default='Unable to fetch data from "${url}". Retry later.',
                            mapping=dict(url=url),
                        ),
                        context=self.request,
                    ),
                )
            )
        if response.status_code != 200:
            message = response.text or response.reason
            return dict(
                error=dict(
                    code=response.status_code,
                    type="InternalServerError",
                    message=message,
                )
            )
        return response.content

    def extract_links(self, html, css_class, css_id, url):
        """ """
        soup = BeautifulSoup(html, "html.parser")
        if css_class:
            root = soup.find_all(class_=css_class)
        elif css_id:
            root = soup.find_all(id=css_id)
        else:
            root = [soup]
        links = []
        for element in root:
            for a_tag in element.findAll("a"):
                href = a_tag.attrs.get("href")
                text = a_tag.text
                if href in HREF_NOT_VALID or href.startswith("javascript:"):
                    # href empty tag
                    continue
                if not href.startswith("http"):
                    url_parsed = urlparse(url)
                    href = "{}://{}/{}".format(
                        url_parsed.scheme, url_parsed.netloc, href.lstrip("/")
                    )
                links.append(dict(href=href, text=text))
        return links

    # def is_file(self, href):
    #     """ """
    #     try:
    #         response = requests.head(href, allow_redirects=True)
    #     except (Timeout, RequestException) as e:
    #         logger.exception(e)
    #         return False
    #     if response.status_code != 200:
    #         return False
    #     content_type = response.headers.get("Content-Type", "")
    #     if content_type.startswith("text/html"):
    #         return False
    #     return True

==> redturtle.filesretriever-1.0.2.tar.gz: redturtle.filesretriever-1.0.2/src/redturtle/filesretriever/restapi/services/files_list.py <==
# -*- coding: utf-8 -*-
from bs4 import BeautifulSoup
from plone.restapi.deserializer import json_body
from plone.restapi.services import Service
from redturtle.filesretriever import _
from requests.adapters import HTTPAdapter
from requests.exceptions import RequestException
from requests.exceptions import Timeout
from urllib.parse import urlparse
from zope.i18n import translate

import logging
import requests
import ssl


# Creazione di un adattatore con TLS 1.2 o superiore
class AddedCipherAdapter(HTTPAdapter):
    """
    This is needed because some websites (e.g. bassareggiana.it) are using old tls versions.
    This is a workaround to decrease the security level of the connection.
    """

    def init_poolmanager(self, *args, **kwargs):
        context = ssl.create_default_context()
        context.set_ciphers("DEFAULT@SECLEVEL=1")
        kwargs["ssl_context"] = context
        super().init_poolmanager(*args, **kwargs)


logger = logging.getLogger(__name__)

HREF_NOT_VALID = ["", None, "#"]


class FilesListService(Service):
    """ """

    def reply(self):
        query = json_body(self.request)
        url = query.get("url", "")

        html = self.fetch_html(url)
        if not html:
            return {}

        css_class = query.get("class", "")
        css_id = query.get("id", "")
        links = self.extract_links(
            html=html, css_class=css_class, css_id=css_id, url=url
        )
        return {"links": links}

    def fetch_html(self, url):
        """ """
        session = requests.Session()
        session.mount("https://", AddedCipherAdapter())
        try:
            response = session.get(url, timeout=10)
        except Timeout as e:
            logger.exception(e)
            return dict(
                error=dict(
                    code="408",
                    type="Timeout",
                    message=translate(
                        _(
                            "request_timeout",
                            default="Unable to fetch data from given url (${url}): timeout. Retry later.",
                            mapping=dict(url=url),
                        ),
                        context=self.request,
                    ),
                )
            )
        except RequestException as e:
            logger.exception(e)
            return dict(
                error=dict(
                    code="500",
                    type="InternalServerError",
                    message=translate(
                        _(
                            "request_error",
                            default='Unable to fetch data from "${url}". Retry later.',
                            mapping=dict(url=url),
                        ),
                        context=self.request,
                    ),
                )
            )
        if response.status_code != 200:
            message = response.text or response.reason
            return dict(
                error=dict(
                    code=response.status_code,
                    type="InternalServerError",
                    message=message,
                )
            )
        return response.content

    def extract_links(self, html, css_class, css_id, url):
        """ """
        soup = BeautifulSoup(html, "html.parser")
        if css_class:
            root = soup.find_all(class_=css_class)
        elif css_id:
            root = soup.find_all(id=css_id)
        else:
            root = [soup]
        links = []
        for element in root:
            for a_tag in element.findAll("a"):
                href = a_tag.attrs.get("href")
                text = a_tag.text
                if href in HREF_NOT_VALID or href.startswith("javascript:"):
                    # href empty tag
                    continue
                if not href.startswith("http"):
                    url_parsed = urlparse(url)
                    href = "{}://{}/{}".format(
                        url_parsed.scheme, url_parsed.netloc, href.lstrip("/")
                    )
                links.append(dict(href=href, text=text))
        return links

    # def is_file(self, href):
    #     """ """
    #     try:
    #         response = requests.head(href, allow_redirects=True)
    #     except (Timeout, RequestException) as e:
    #         logger.exception(e)
    #         return False
    #     if response.status_code != 200:
    #         return False
    #     content_type = response.headers.get("Content-Type", "")
    #     if content_type.startswith("text/html"):
    #         return False
    #     return True
